Python: module VirtualEnvOnDemand.exceptions

VirtualEnvOnDemand.exceptions | index

`exceptions - A list of exceptions specific to VirtualEnvOnDemand`

Classes
`` |  | exceptions.Exception(exceptions.BaseException) PipInstallFailed VirtualEnvDoesNotExist
class PipInstallFailed(exceptions.Exception)
`` | `PipInstallFailed - Exception raised when pip fails to install a list of packages`
| Method resolution order: PipInstallFailed exceptions.Exception exceptions.BaseException __builtin__.object Methods defined here: __init__(self, returnCode=None, reqFileContents='') `Create a PipInstallFailed exception, building a message from some pieces of information @param returnCode <int> - Return code of subprocess, or None if undetermined @param reqFileContents <str> - String of requirements file to reproduce error` Data descriptors defined here: __weakref__ `list of weak references to the object (if defined)` Data and other attributes inherited from exceptions.Exception: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from exceptions.BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from exceptions.BaseException: __dict__ args message
class VirtualEnvDoesNotExist(exceptions.Exception)
`` | `VirtualEnvDoesNotExist - Exception raised when an attempt to install into a virtualenv directory that does not exist`
| Method resolution order: VirtualEnvDoesNotExist exceptions.Exception exceptions.BaseException __builtin__.object Data descriptors defined here: __weakref__ `list of weak references to the object (if defined)` Methods inherited from exceptions.Exception: __init__(...) `x.__init__(...) initializes x; see help(type(x)) for signature` Data and other attributes inherited from exceptions.Exception: __new__ = <built-in method __new__ of type object> `T.__new__(S, ...) -> a new object with type S, a subtype of T` Methods inherited from exceptions.BaseException: __delattr__(...) `x.__delattr__('name') <==> del x.name` __getattribute__(...) `x.__getattribute__('name') <==> x.name` __getitem__(...) `x.__getitem__(y) <==> x[y]` __getslice__(...) `x.__getslice__(i, j) <==> x[i:j] Use of negative indices is not supported.` __reduce__(...) __repr__(...) `x.__repr__() <==> repr(x)` __setattr__(...) `x.__setattr__('name', value) <==> x.name = value` __setstate__(...) __str__(...) `x.__str__() <==> str(x)` __unicode__(...) Data descriptors inherited from exceptions.BaseException: __dict__ args message

Data
`` |  | __all__ = ('PipInstallFailed', 'VirtualEnvDoesNotExist')